@@ -50,7 +50,8 @@ sub CreateSessionID {
     my $UserType;
 
     # get params
-    my $PostPw = $Param{Data}->{Password} || '';
+    my $PostPw             = $Param{Data}->{Password}       || '';
+    my $PostTwoFactorToken = $Param{Data}->{TwoFactorToken} || '';
 
     if ( defined $Param{Data}->{UserLogin} && $Param{Data}->{UserLogin} ) {
 
@@ -59,8 +60,9 @@ sub CreateSessionID {
 
         # check submitted data
         $User = $Kernel::OM->Get('Kernel::System::Auth')->Auth(
-            User => $PostUser,
-            Pw   => $PostPw,
+            User           => $PostUser,
+            Pw             => $PostPw,
+            TwoFactorToken => $PostTwoFactorToken,
         );
         %UserData = $Kernel::OM->Get('Kernel::System::User')->GetUserData(
             User  => $User,
@@ -75,8 +77,9 @@ sub CreateSessionID {
 
         # check submitted data
         $User = $Kernel::OM->Get('Kernel::System::CustomerAuth')->Auth(
-            User => $PostUser,
-            Pw   => $PostPw,
+            User           => $PostUser,
+            Pw             => $PostPw,
+            TwoFactorToken => $PostTwoFactorToken,
         );
         %UserData = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerUserDataGet(
             User  => $PostUser,
