@@ -12,8 +12,6 @@ package Kernel::Modules::AdminGenericAgent;
 use strict;
 use warnings;
 
-use URI::Escape;
-
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::Language qw(Translatable);
 
@@ -304,7 +302,7 @@ sub Run {
                     )
                 {
                     my $Profile = $Self->{Profile} || '';
-                    $Profile = uri_escape($Profile);    # See internal issue #477.
+                    $Profile = $LayoutObject->LinkEncode($Profile);    # See internal issues #477 and #684.
                     return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=Update;Profile=$Profile" );
                 }
                 else {
