@@ -1,6 +1,6 @@
 // --
 // Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-// Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+// Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -793,7 +793,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                             StartElement: StartElement,
                             EndElement: EndElement
                         };
-                        TargetNS.HighlightTransitionLabel(labelOverlay, StartElement, EndElement);
+                        TargetNS.HighlightTransitionLabel(labelOverlay);
                         originalEvent.stopPropagation();
                         return false;
                     },
@@ -833,7 +833,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             // Do not open path dialog for dummy connections
             // dblclick on overlays (e.g. labels) propagate to the connection
             // prevent opening path dialog twice if clicked on label
-            if (EndActivityObject !== 'Dummy' && !$(Event.srcElement).hasClass('TransitionLabel')) {
+            if (EndActivityObject.elementId !== 'Dummy' && !$(Event.srcElement).hasClass('TransitionLabel')) {
                 Core.Agent.Admin.ProcessManagement.ShowOverlay();
 
                 if (!Core.Config.Get('SessionIDCookie') && PopupPath.indexOf(SessionData[Core.Config.Get('SessionName')]) === -1) {
@@ -841,6 +841,22 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                 }
 
                 Core.UI.Popup.OpenPopup(PopupPath, 'Path');
+            } else {
+                Core.UI.Dialog.ShowContentDialog(
+                    $('#Dialogs #TransitionMissingActivityDialog'),
+                    Core.Language.Translate('Edit Transition "%s"', Core.App.EscapeHTML(TransitionName)),
+                    '240px',
+                    'Center',
+                    true,
+                    [
+                        {
+                            Label: Core.Language.Translate('OK'),
+                            Function: function () {
+                                Core.UI.Dialog.CloseDialog($('.Dialog'));
+                            }
+                        },
+                    ]
+                );
             }
             Event.stopImmediatePropagation();
             return false;
@@ -851,14 +867,11 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
      * @name HighlightTransitionLabel
      * @memberof Core.Agent.Admin.ProcessManagement.Canvas
      * @function
-     * @param {String} Connection
-     * @param {String} StartActivity
-     * @param {String} EndActivity
+     * @param {Object} Connection
      * @description
      *      Highlight transition label.
      */
-    TargetNS.HighlightTransitionLabel = function(Connection, StartActivity, EndActivity) {
-
+    TargetNS.HighlightTransitionLabel = function(Connection) {
         var Config = Core.Agent.Admin.ProcessManagement.ProcessData,
             ConfigProcess = Config = Core.Config.Get('ConfigProcess'),
             ProcessEntityID = $('#ProcessEntityID').val(),
@@ -866,7 +879,8 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             TransitionEntityID = Connection.component.getParameter('TransitionID'),
             StartActivityID = Connection.component.sourceId,
             PopupPath = ConfigProcess.PopupPathPath + "ProcessEntityID=" + ProcessEntityID + ";TransitionEntityID=" + TransitionEntityID + ";StartActivityID=" + StartActivityID,
-            SessionData = Core.App.GetSessionInformation();
+            SessionData = Core.App.GetSessionInformation(),
+            EndActivity = Connection.component.targetId;
 
         if (TargetNS.DragTransitionAction) {
             $(Connection.canvas).addClass('ReadyToDrop');
@@ -890,7 +904,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             });
         }
 
-        if (!$(Connection.canvas).find('.Edit').length) {
+        if (!$(Connection.canvas).find('.Edit').length && EndActivity !== 'Dummy') {
             $(Connection.canvas).append('<a class="Edit" title="' + Core.Language.Translate('Edit this transition') + '" href="#"><i class="fa fa-edit"></i></a>').find('.Edit').on('click', function(Event) {
                 if (EndActivity !== 'Dummy') {
                     if (!Core.Config.Get('SessionIDCookie') && PopupPath.indexOf(SessionData[Core.Config.Get('SessionName')]) === -1) {
@@ -909,7 +923,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         Connection.component.setPaintStyle({ strokeStyle: "#FF9922", lineWidth: '2' });
 
         // show tooltip with assigned transition actions
-        TargetNS.ShowTransitionTooltip(Connection, StartActivity);
+        TargetNS.ShowTransitionTooltip(Connection, StartActivityID);
 
         $(Connection.canvas).off('dblclick.Transition').on('dblclick.Transition', function(Event) {
             if (EndActivity !== 'Dummy') {
