@@ -84,7 +84,7 @@ Core.UI.Popup = (function (TargetNS) {
             WindowURLParams: "dependent=yes,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,toolbar=no",
             Left: 100,
             Top: 100,
-            Width: 1040,
+            Width: 1200,
             Height: 700
         }
     };
@@ -427,6 +427,24 @@ Core.UI.Popup = (function (TargetNS) {
         }
     };
 
+    /**
+     * @name UpdatePopupProfile
+     * @memberof Core.UI.Popup
+     * @function
+     * @param {Object} Param        - The object contains PopupProfile data.
+     * @param {String} Param.Left   - x (horizontal) coordinates of the window relative to the screen in pixels.
+     * @param {String} Param.Top    - y (vertical) coordinates of the window relative to the screen in pixels.
+     * @param {String} Param.Width  - Width in pixels.
+     * @param {String} Param.Height - Height in pixels.
+     * @description
+     *      This function updates the popup profile preferences of given user.
+     */
+    TargetNS.UpdatePopupProfile = function (Param) {
+        $.each(Param, function (Key, Value) {
+            Core.Agent.PreferencesUpdate('UserPopupProfile' + Key, Value);
+        });
+    };
+
     /**
      * @name OpenPopup
      * @memberof Core.UI.Popup
@@ -444,6 +462,9 @@ Core.UI.Popup = (function (TargetNS) {
             NewWindow,
             WindowName,
             ConfirmClosePopup = true,
+            Regex,
+            WidthResult,
+            HeightResult,
             PopupFeatures;
 
         // If we are in a mobile environment on opening the popup, open it as an iframe
@@ -491,9 +512,32 @@ Core.UI.Popup = (function (TargetNS) {
 
                 if (WindowMode === 'Popup') {
                     PopupFeatures = PopupProfiles[PopupProfile].WindowURLParams;
+
+                    // Convert strings to numbers to avoid surprises like concatenation instead of sum.
+                    PopupProfiles[PopupProfile].Width = Number(PopupProfiles[PopupProfile].Width);
+                    PopupProfiles[PopupProfile].Height = Number(PopupProfiles[PopupProfile].Height);
+                    PopupProfiles[PopupProfile].Top = Number(PopupProfiles[PopupProfile].Top);
+                    PopupProfiles[PopupProfile].Left = Number(PopupProfiles[PopupProfile].Left);
+
+                    // get pixel or percent of width and height
+                    // convert to a valid pixel value for window.open
+                    Regex        = new RegExp('(%|px)$');
+                    WidthResult  = PopupProfiles[PopupProfile].Width.toString().match(Regex);
+                    HeightResult = PopupProfiles[PopupProfile].Height.toString().match(Regex);
+
+                    if (PopupProfiles[PopupProfile].Width && WidthResult && WidthResult[0]){
+                        PopupProfiles[PopupProfile].Width = PopupProfiles[PopupProfile].Width.replace(WidthResult[0],'');
+                        PopupProfiles[PopupProfile].Width = PopupProfiles[PopupProfile].Width * window.screen.availWidth / 100;
+                    }
+
+                    if (PopupProfiles[PopupProfile].Height && HeightResult && HeightResult[0]){
+                        PopupProfiles[PopupProfile].Height = PopupProfiles[PopupProfile].Height.replace(HeightResult[0],'');
+                        PopupProfiles[PopupProfile].Height = PopupProfiles[PopupProfile].Height * window.screen.availHeight / 100;
+                    }
+
                     // Get the position of the current screen on browsers which support it (non-IE) and
-                    //  use it to open the popup on the same screen
-                    PopupFeatures += ',left=' + ((window.screen.left || 0) + PopupProfiles[PopupProfile].Left);
+                    // use it to open the popup on the same screen
+                    PopupFeatures += ',left=' + PopupProfiles[PopupProfile].Left;
                     PopupFeatures += ',width=' + PopupProfiles[PopupProfile].Width;
 
                     // Bug#11205 (http://bugs.otrs.org/show_bug.cgi?id=11205)
@@ -505,11 +549,11 @@ Core.UI.Popup = (function (TargetNS) {
                     if (window.screen.availHeight < PopupProfiles[PopupProfile].Height + PopupProfiles[PopupProfile].Top) {
                         PopupFeatures += ',height=' + (window.screen.availHeight - PopupProfiles[PopupProfile].Top - 20);
                         // Adjust top position to have the same distance between top and bottom line.
-                        PopupFeatures += ',top=' + ((window.screen.top || 0) + (PopupProfiles[PopupProfile].Top / 2));
+                        PopupFeatures += ',top=' + (PopupProfiles[PopupProfile].Top / 2);
                     }
                     else {
                         PopupFeatures += ',height=' + PopupProfiles[PopupProfile].Height;
-                        PopupFeatures += ',top=' + ((window.screen.top || 0) + PopupProfiles[PopupProfile].Top);
+                        PopupFeatures += ',top=' + PopupProfiles[PopupProfile].Top;
                     }
 
                     NewWindow = window.open(URL, WindowName, PopupFeatures);
@@ -688,6 +732,7 @@ Core.UI.Popup = (function (TargetNS) {
     TargetNS.Init = function () {
 
         var PopupURL,
+            UpdatePopupProfileTimeout,
             PopupClose = Core.Config.Get('PopupClose');
 
         if (PopupClose === 'LoadParentURLAndClose') {
@@ -731,6 +776,24 @@ Core.UI.Popup = (function (TargetNS) {
             // add a class to the body element, if this popup is a real popup
             if (window.opener) {
                 $('body').addClass('RealPopup');
+
+                $(window).on('resize', function(){
+
+                    if(UpdatePopupProfileTimeout) {
+                        clearTimeout(UpdatePopupProfileTimeout);
+                    }
+
+                    // update popup profile data after 3 seconds
+                    UpdatePopupProfileTimeout = setTimeout(function() {
+                        var Param = {
+                            Height: $(window).height(),
+                            Width:  $(window).width(),
+                            Left:   window.screenX,
+                            Top:    window.screenY,
+                        };
+                       TargetNS.UpdatePopupProfile(Param);
+                    },1000);
+                });
             }
         }
     };
